diff --git a/README b/README
index a8126b6..f7aac01 100644
--- a/README
+++ b/README
@@ -37,6 +37,14 @@ Project MESSAGE: Building for QT5+...
 $ make
 ...
 
+To build the runtime in debug mode, use the below option along with qmake
+$ qmake CONFIG+=debug
+
+To build the runtime in release mode, use the below option along with qmake
+$ qmake CONFIG+=release
+
+By default (without CONFIG option) , runtime application will be built in release mode.
+
 On Linux, an executable called 'pgAdmin4' will be built, and on Mac OS X, an
 app bundle called pgAdmin4.app will be created.
 
diff --git a/runtime/BrowserWindow.cpp b/runtime/BrowserWindow.cpp
index 409ece9..7d94aaa 100644
--- a/runtime/BrowserWindow.cpp
+++ b/runtime/BrowserWindow.cpp
@@ -57,6 +57,13 @@ BrowserWindow::BrowserWindow(QString url)
     m_tabGridLayout->setContentsMargins(0, 0, 0, 0);
     m_mainWebView = new WebViewWindow(m_pgAdminMainTab);
 
+#ifdef PGADMIN4_DEBUG
+    // If pgAdmin4 application is run in debug mode, then we should allow to display
+    // "Inspect" option, when user right click on QWebView widget.
+    // This option is useful to debug the pgAdmin4 desktop application and open the developer tool like browser.
+    QWebSettings::globalSettings()->setAttribute(QWebSettings::DeveloperExtrasEnabled, true);
+#endif
+
     m_tabGridLayout->addWidget(m_mainWebView, 0, 0, 1, 1);
     m_tabWidget->addTab(m_pgAdminMainTab, QString());
     m_tabWidget->setCurrentIndex(0);
diff --git a/runtime/pgAdmin4.pro b/runtime/pgAdmin4.pro
index 6aa0361..339e158 100644
--- a/runtime/pgAdmin4.pro
+++ b/runtime/pgAdmin4.pro
@@ -7,6 +7,11 @@ greaterThan(QT_MAJOR_VERSION, 4) {
     QT += webkit network 
 }
 
+CONFIG(debug, debug|release) {
+  DEFINES += PGADMIN4_DEBUG
+  message(Configure pgAdmin4 to run in debug mode...)
+}
+
 win32 {
     message(Building for Windows...)
 
